@@ -1,5 +1,3 @@
-from distutils.version import StrictVersion
-
 import django
 
 from django.forms.widgets import DateInput, DateTimeInput, TimeInput, Widget
@@ -11,29 +9,16 @@ from is_core.forms.widgets import (DragAndDropFileInput, ReadonlyWidget, URLRead
                                    FileReadonlyWidget, FulltextSelectMultiple, NullBooleanReadonlyWidget)
 
 
-if StrictVersion(django.get_version()) < StrictVersion('1.11'):
-    def build_attrs(self, extra_attrs=None, **kwargs):
-        """ Helper function for building an attribute dictionary. """
-        attrs = dict(self.attrs, **kwargs)
-        if extra_attrs:
-            attrs.update(extra_attrs)
-        if self.class_name:
-            attrs = add_class_name(attrs, self.class_name)
-        if self.placeholder:
-            attrs['placeholder'] = self.placeholder
-        return attrs
-else:
-    def build_attrs(self, base_attrs, extra_attrs=None, **kwargs):
-        """ Helper function for building an attribute dictionary. """
-        attrs = dict(base_attrs, **kwargs)
-        if extra_attrs:
-            attrs.update(extra_attrs)
-        if self.class_name:
-            attrs = add_class_name(attrs, self.class_name)
-        if self.placeholder:
-            attrs['placeholder'] = self.placeholder
-        return attrs
-
+def build_attrs(self, base_attrs, extra_attrs=None, **kwargs):
+    """ Helper function for building an attribute dictionary. """
+    attrs = dict(base_attrs, **kwargs)
+    if extra_attrs:
+        attrs.update(extra_attrs)
+    if self.class_name:
+        attrs = add_class_name(attrs, self.class_name)
+    if self.placeholder:
+        attrs['placeholder'] = self.placeholder
+    return attrs
 
 
 Widget.placeholder = None
